@@ -1,3 +1,4 @@
+import peewee
 from peewee import *
 #from porerefiner.config import config
 
@@ -13,6 +14,11 @@ import tempfile
 from copy import copy, deepcopy
 from itertools import chain
 
+logging.addLevelName(logging.DEBUG - 5, 'TRACE')
+
+#slightly demote the Peewee debug logging
+peewee.logger.debug = lambda msg, *a, **k: peewee.logger.log(logging.DEBUG - 5, msg, *a, **k)
+
 
 _db = SqliteDatabase(None)
 
